summaryrefslogtreecommitdiffstats
path: root/src/arch/i386/prefix/pxeprefix.S
diff options
context:
space:
mode:
Diffstat (limited to 'src/arch/i386/prefix/pxeprefix.S')
-rw-r--r--src/arch/i386/prefix/pxeprefix.S7
1 files changed, 6 insertions, 1 deletions
diff --git a/src/arch/i386/prefix/pxeprefix.S b/src/arch/i386/prefix/pxeprefix.S
index 55a228ffc..8c091df64 100644
--- a/src/arch/i386/prefix/pxeprefix.S
+++ b/src/arch/i386/prefix/pxeprefix.S
@@ -220,7 +220,9 @@ get_physical_device:
jmp no_physical_device
pci_physical_device:
- /* Record PCI bus:dev.fn */
+ /* Record PCI bus:dev.fn and vendor/device IDs */
+ movl ( pxe_parameter_structure + 0x03 ), %eax
+ movl %eax, pci_vendor
movw ( pxe_parameter_structure + 0x0b ), %ax
movw %ax, pci_busdevfn
movw $10f, %si
@@ -680,6 +682,9 @@ pci_busdevfn: .word 0xffff
isapnp_csn: .word 0xffff
isapnp_read_port: .word 0xffff
+pci_vendor: .word 0
+pci_device: .word 0
+
.equ undi_device_size, ( . - undi_device )
/*****************************************************************************